OC.L10N.register(
    "files",
    {
    "File could not be found" : "ファイルを見つけられませんでした",
    "Move or copy" : "移動またはコピー",
    "Download" : "ダウンロード",
    "Delete" : "削除",
    "Tags" : "タグ",
    "Show list view" : "リストビューで表示",
    "Show grid view" : "グリッドビューで表示",
    "Home" : "ホーム",
    "Close" : "閉じる",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "This will stop your current uploads." : "現在のアップロードが停止されます。",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "Processing files …" : "ファイルの処理中...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
    "Not enough free space" : "十分な空き容量がありません",
    "An unknown error has occurred" : "不明なエラーが発生しました",
    "File could not be uploaded" : "ファイルをアップロードできませんでした",
    "Uploading …" : "アップロード中...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
    "Actions" : "アクション",
    "Rename" : "名前の変更",
    "Move" : "移動",
    "Copy" : "コピー",
    "Choose target folder" : "ターゲットフォルダーを選択",
    "Set reminder" : "リマインダーを設定",
    "Edit locally" : "ローカルで編集",
    "Open" : "開く",
    "_Delete file_::_Delete files_" : ["ファイルの削除"],
    "_Delete folder_::_Delete folders_" : ["フォルダを削除"],
    "_Disconnect storage_::_Disconnect storages_" : ["ストレージを切断する"],
    "_Leave this share_::_Leave these shares_" : ["これらの共有から抜ける"],
    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
    "Files" : "ファイル",
    "Details" : "詳細",
    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
    "Apply tag(s) to selection" : "選択項目にタグを適用",
    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
    "Pending" : "保留中",
    "Unable to determine date" : "更新日不明",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "copy" : "コピー",
    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
    "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "New file/folder menu" : "新規ファイル/フォルダメニュー",
    "Select file range" : "ファイルを範囲選択",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} / {quota} 使用中",
    "{used} used" : "{used} 使用中",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
    "View in folder" : "フォルダー内で表示",
    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Favorite" : "お気に入り",
    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
    "New folder" : "新しいフォルダー",
    "Create new folder" : "新しいフォルダーを作成",
    "Upload file" : "ファイルをアップロード",
    "Recent" : "最新",
    "Not favorited" : "お気に入りではありません",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "Added to favorites" : "お気に入りに追加",
    "Removed from favorites" : "お気に入りから削除",
    "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
    "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
    "Favorites" : "お気に入り",
    "File changes" : "ファイル更新",
    "Created by {user}" : "{user} が作成しました",
    "Changed by {user}" : "{user} が更新しました",
    "Deleted by {user}" : "{user} が削除しました",
    "Restored by {user}" : "{user} が復元しました",
    "Renamed by {user}" : "{user} が作成しました",
    "Moved by {user}" : "{user} が移動しました",
    "\"remote account\"" : "\"リモートアカウント\"",
    "You created {file}" : "{file} を作成しました",
    "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
    "{user} created {file}" : "{user} が {file} を作成しました",
    "{user} created an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを作成しました",
    "{file} was created in a public folder" : "公開フォルダーに {file} が作成されました",
    "You changed {file}" : "{file} を更新しました",
    "You changed an encrypted file in {file}" : "{file}で暗号化されたファイルを変更しました。",
    "{user} changed {file}" : "{user} が {file} を更新しました",
    "{user} changed an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを変更しました",
    "You deleted {file}" : "{file} を削除しました",
    "You deleted an encrypted file in {file}" : "{file}で暗号化されたファイルを削除しました。",
    "{user} deleted {file}" : "{user} が {file} を削除しました",
    "{user} deleted an encrypted file in {file}" : "{user}が{file}で暗号化されたファイルを削除しました",
    "You restored {file}" : "{file} を復元しました",
    "{user} restored {file}" : "{user} が {file} を復元しました",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile}(非表示) の名前を {newfile}(非表示) に変更しました",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (非表示)の名前を{newfile}に変更しました",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}の名前を{newfile}(非表示)に変更しました",
    "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} は {oldfile}(非表示) の名前を {newfile}(非表示)  に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} は {oldfile} (非表示) の名前を {newfile} に変更しました",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}は{oldfile}を{newfile} (非表示)に名前変更しました",
    "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
    "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
    "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
    "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "Accept" : "承諾",
    "Reject" : "拒否",
    "Incoming ownership transfer from {user}" : "{user} からの所有権転送を受信",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} を承諾しますか？\n\n注意：承諾後の転送処理には最大 1 時間かかる場合があります。",
    "Ownership transfer failed" : "所有権の譲渡に失敗しました",
    "Your ownership transfer of {path} to {user} failed." : "{path}の{user}への所有権転送に失敗しました。",
    "The ownership transfer of {path} from {user} failed." : "{user} からの {path} の所有権転送に失敗しました。",
    "Ownership transfer done" : "所有権の譲渡が完了しました",
    "Your ownership transfer of {path} to {user} has completed." : "{user} への {path} の所有権転送が完了しました。",
    "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
    "in %s" : "%s で",
    "File Management" : "ファイル管理",
    "Current directory path" : "現在のディレクトリパス",
    "Reload current directory" : "カレントディレクトリの再読み込み",
    "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
    "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
    "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
    "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
    "Files uploaded successfully" : "ファイルが正常にアップロードされました",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行された",
    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
    "Toggle selection for file \"{displayName}\"" : "ファイル \"{displayName}\" の選択を切り替える",
    "Toggle selection for folder \"{displayName}\"" : "フォルダ \"{displayName}\" の選択を切り替える",
    "Rename file" : "ファイル名の変更",
    "File name" : "ファイル名",
    "Folder name" : "フォルダー名",
    "This node is unavailable" : "このノードは利用できません",
    "Download file {name}" : "ファイル {name} をダウンロード",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" は許可されたファイルタイプではありません。",
    "{newName} already exists." : "{newName} すでに存在しています。",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\"はファイル名には使用できません。",
    "Name cannot be empty" : "名前は空にできません",
    "Another entry with the same name already exists" : "同じ名前の別のエントリがすでに存在しています",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
    "Total rows summary" : "総行数のサマリー",
    "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
    "\"{displayName}\" failed on some elements " : "いくつかの要素で \"{displayName}\" が失敗しました。",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
    "List of files and folders." : "ファイルとフォルダの一覧。",
    "Column headers with buttons are sortable." : "ボタン付きの列ヘッダはソート可能です。",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
    "File not found" : "ファイルが見つかりません",
    "Storage informations" : "ストレージ情報",
    "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
    "{relative}% used" : "{relative}% 使用されています",
    "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
    "Your storage is full, files can not be updated or synced anymore!" : "ストレージは一杯です。ファイルの更新と同期はできません！",
    "Create" : "作成",
    "A file or folder with that name already exists." : "その名前のファイルまたはフォルダーは既に存在しています。",
    "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
    "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Change" : "変更",
    "New owner" : "新しい所有者",
    "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Transfer" : "転送",
    "Transfer {path} to {userid}" : "{path} を {userid} に転送する",
    "Invalid path selected" : "無効なパスが選択されました",
    "Unknown error" : "不明なエラー",
    "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
    "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
    "Choose file" : "ファイルを選択",
    "Choose {file}" : "{file}を選択",
    "Loading current folder" : "現在のフォルダの読み込み中",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "Go to the previous folder" : "前のフォルダへ移動",
    "Go back" : "戻る",
    "Share" : "共有",
    "Shared by link" : "URLリンクで共有中",
    "Shared" : "共有中",
    "Switch to list view" : "リスト表示へ切り替え",
    "Switch to grid view" : "グリッド表示へ切り替え",
    "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
    "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
    "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
    "Open the files app settings" : "ファイルアプリの設定を開く",
    "Files settings" : "ファイルの設定",
    "File cannot be accessed" : "ファイルにアクセスできません",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ファイルが見つからないか、あなたがそれを表示する権限を持っていない可能性があります。送信者に共有するように依頼してください。",
    "Sort favorites first" : "お気に入りを最初に並べる",
    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
    "Show hidden files" : "隠しファイルを表示",
    "Crop image previews" : "プレビュー画像を切り抜く",
    "Enable the grid view" : "グリッド表示を有効にする",
    "Additional settings" : "追加設定",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "クリップボードにコピー",
    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
    "Clipboard is not available" : "クリップボードは利用できません",
    "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
    "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
    "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
    "Pick a template for {name}" : "{name} のテンプレートを選択してください",
    "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
    "Creating file" : "ファイル作成",
    "Blank" : "ブランク",
    "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
    "Delete permanently" : "完全に削除する",
    "Delete and unshare" : "削除して共有を解除",
    "You are about to delete {count} items." : "あなたは {count} 個のアイテムを削除しようとしています。",
    "Confirm deletion" : "削除の確認",
    "Cancel" : "キャンセル",
    "Deletion cancelled" : "削除はキャンセルされました",
    "Destination is not a folder" : "宛先がフォルダではありません",
    "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
    "(copy)" : "(copy)",
    "(copy %n)" : "(copy %n)",
    "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
    "The file does not exist anymore" : "ファイルはもう存在しません",
    "Choose destination" : "移動先を選択",
    "Copy to {target}" : "{target} にコピー",
    "Move to {target}" : "{target} に移動",
    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
    "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
    "Open folder {displayName}" : "フォルダ {displayName} を開く",
    "Open in Files" : "ファイルアプリで開く",
    "Open details" : "詳細を開く",
    "An error occurred while uploading. Please try again later." : "アップロード中にエラーが発生しました。後でもう一度お試しください。",
    "Could not copy {file}. {message}" : "{file} をコピーできませんでした。 {message}",
    "Could not move {file}. {message}" : "{file} を移動できませんでした。 {message}",
    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
    "Filename" : "ファイル名",
    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
    "Create new templates folder" : "新しいテンプレートフォルダーを作成",
    "Templates" : "テンプレート",
    "New template folder" : "新しいテンプレートフォルダ",
    "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
    "Uploading \"{filename}\" failed" : "\"{filename}\" のアップロードに失敗しました",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ファイルと 1 フォルダ"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} ファイルと {folderCount} フォルダ",
    "List of favorites files and folders." : "お気に入りのファイルやフォルダーの一覧",
    "No favorites yet" : "まだお気に入りはありません",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "All files" : "すべてのファイル",
    "List of your files and folders." : "ファイルやフォルダーの一覧",
    "Personal Files" : "個人ファイル",
    "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
    "No personal files found" : "個人ファイルは見つかりませんでした",
    "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
    "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
    "No recently modified files" : "最近更新されたファイルはありません",
    "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成",
    "Direct link was copied (only works for users who have access to this file/folder)" : "直接リンクがコピーされました（ただしこのファイルやフォルダにアクセスできる人だけが使用可能です）",
    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
    "You can only favorite a single file or folder at a time" : "お気に入りに追加できるファイルまたはフォルダーは一度に1つまでです",
    "\"remote user\"" : "\"リモートユーザー\"",
    "Search users" : "ユーザーを検索",
    "You might not have have permissions to view it, ask the sender to share it" : "閲覧権限がない可能性があるため、送信者に共有を依頼してください",
    "Set up templates folder" : "テンプレートフォルダーを設定",
    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
    "Toggle grid view" : "グリッド表示の切り替え",
    "Deleted files" : "ゴミ箱",
    "Shares" : "共有",
    "Shared with others" : "他ユーザーと共有中",
    "Shared with you" : "他ユーザーがあなたと共有中",
    "Deleted shares" : "削除された共有",
    "Pending shares" : "保留中の共有",
    "This file has the tag {tag}" : "このファイルには {tag} タグがあります。",
    "This file has the tags {firstTags} and {lastTag}" : "このファイルには {firstTags} と {lastTag} というタグがあります",
    "Select the row for {displayName}" : "{displayName} の行を選択する",
    "Open folder {name}" : "フォルダ {name} を開く",
    "Unselect all" : "すべて選択解除",
    "ascending" : "昇順",
    "descending" : "降順",
    "Sort list by {column} ({direction})" : "{column} ({direction}) でリストを並べ替える",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
    "Search for an account" : "アカウントを検索",
    "Choose" : "選択",
    "No files or folders have been deleted yet" : "まだ削除されたファイルやフォルダはありません",
    "Add" : "追加",
    "The files is locked" : "ファイルはロックされています"
},
"nplurals=1; plural=0;");
